%define subrel 2

Name:           puppet3
Version:        3.2.4
Release:        %mkrel 1
Summary:        System Automation and Configuration Management Software
License:        Apache Software License
Group:          Monitoring
URL:            http://www.puppetlabs.com/
Source0:        http://puppetlabs.com/downloads/puppet/puppet-%{version}.tar.gz
Source102:      puppet-tmpfiles.conf
Patch0:         CVE-2013-4969-3.2.x-temp-file.patch
Patch1:         CVE-2013-4969-regression.patch
BuildArch:      noarch
BuildRequires:  ruby
BuildRequires:  facter
Requires:       facter
Requires:       ruby-hiera
Suggests:       vim-puppet3
Suggests:       emacs-puppet3
Requires(post): systemd >= %{systemd_required_version}
Requires(pre):  rpm-helper
Requires(post): rpm-helper
Requires(preun):rpm-helper
Conflicts:      puppet

%description
Puppet lets you centrally manage every important aspect of your system using a 
cross-platform specification language that manages all the separate elements 
normally aggregated in different files, like users, cron jobs, and hosts, 
along with obviously discrete elements like packages, services, and files.

This package provide the puppet client daemon.

%package server
Group:          Monitoring 
Summary:        Server for the puppet system management tool
Requires:       %{name} = %{version}
Requires(post): rpm-helper
Requires(preun):rpm-helper
Conflicts:      puppet-server

%description server
Provides the central puppet server daemon (puppetmaster) which provides
manifests to clients.
The server can also function as a certificate authority and file server.

%package -n vim-puppet3
Group:          Editors
Summary:        Syntax highlighting for puppet manifests in vim
Conflicts:      vim-puppet

%description -n vim-puppet3
The vim-puppet package provides filetype detection and syntax highlighting for
puppet manifests (files ending with ".pp").

%package -n emacs-puppet3
Group:          Editors
Summary:        Syntax highlighting for puppet manifests in emacs
Conflicts:      emacs-puppet

%description -n emacs-puppet3
The emacs-puppet package provides filetype detection and syntax highlighting for
puppet manifests (files ending with ".pp").

%prep
%setup -q -n puppet-%{version}
%patch0 -p 1
%patch1 -p 1

# Fix some rpmlint complaints
for f in mac_automount.pp  mcx_dock_absent.pp  mcx_dock_default.pp \
    mcx_dock_full.pp mcx_dock_invalid.pp mcx_nogroup.pp \
    mcx_notexists_absent.pp; do
    sed -i -e'1d' examples/$f
    chmod a-x examples/$f
done
for f in external/nagios.rb relationship.rb; do
    sed -i -e '1d' lib/puppet/$f
done
chmod +x ext/puppet-load.rb ext/regexp_nodes/regexp_nodes.rb

%build

%install
rm -rf %{buildroot}

ruby install.rb \
    --destdir=%{buildroot} \
    --sitelibdir=%{ruby_vendorlibdir} \
    --quick \
    --no-rdoc

install -d -m 0755 %{buildroot}%{_sysconfdir}/puppet/manifests
install -d -m 0755 %{buildroot}%{_sysconfdir}/puppet/modules
install -d -m 0755 %{buildroot}%{_datadir}/puppet/modules
install -d -m 0755 %{buildroot}%{_localstatedir}/lib/puppet
install -d -m 0755 %{buildroot}%{_localstatedir}/log/puppet

install -D -m 644 ext/systemd/puppetagent.service \
    %{buildroot}%{_unitdir}/puppetagent.service
install -D -m 644 ext/systemd/puppetmaster.service \
    %{buildroot}%{_unitdir}/puppetmaster.service

install -D -m 644 ext/redhat/fileserver.conf \
    %{buildroot}%{_sysconfdir}/puppet/fileserver.conf
install -D -m 644 ext/redhat/puppet.conf \
    %{buildroot}%{_sysconfdir}/puppet/puppet.conf
install -D -m 644 %{SOURCE102} %{buildroot}%{_tmpfilesdir}/puppet.conf

install -d %{buildroot}%{_sysconfdir}/logrotate.d
cat > %{buildroot}%{_sysconfdir}/logrotate.d/puppet <<EOF
/var/log/puppet/*log {
    missingok
    notifempty
    create 0644 puppet puppet
    sharedscripts
    postrotate
        /bin/systemctl reload puppetagent.service > /dev/null 2>/dev/null || true
        /bin/systemctl reload puppetmaster.service > /dev/null 2>/dev/null || true
    endscript
EOF

install -d %{buildroot}%{_datadir}/puppet
cp -a ext/ %{buildroot}%{_datadir}/puppet
# emacs and vim bits are installed elsewhere
rm -rf %{buildroot}%{_datadir}/puppet/ext/{emacs,vim}
# remove misc packaging artifacts in source not applicable to rpm
rm -rf %{buildroot}%{_datadir}/puppet/ext/{gentoo,freebsd,solaris,suse,windows,osx,ips,debian}
rm -f %{buildroot}%{_datadir}/puppet/ext/{build_defaults.yaml,project_data.yaml}
rm -f %{buildroot}%{_datadir}/puppet/ext/redhat/*.init

# vim syntax file
vimdir=%{buildroot}%{_datadir}/vim
install -D -m 644 ext/vim/syntax/puppet.vim $vimdir/syntax/puppet.vim
install -D -m 644 ext/vim/ftdetect/puppet.vim $vimdir/ftdetect/puppet.vim

# emacs syntax file
emacsdir=%{buildroot}%{_datadir}/emacs/site-lisp
install -D -m 644 ext/emacs/puppet-mode.el $emacsdir/puppet-mode.el
install -D -m 644 ext/emacs/puppet-mode-init.el \
    $emacsdir/site-start.d/puppet-mode-init.el

# logcheck files
logcheckdir=%{buildroot}%{_sysconfdir}/logcheck/
install -D -m 644 ext/logcheck/puppet $logcheckdir/ignore.d.server/puppet
install -D -m 644 ext/logcheck/puppet $logcheckdir/ignore.d.workstation/puppet

%pre
%_pre_useradd puppet %{_localstatedir}/lib/puppet /sbin/nologin

%post
%_tmpfilescreate puppet
%_post_service puppetagent

%preun
%_preun_service puppetagent

%post server
%_post_service puppetmaster

%preun server
%_preun_service puppetmaster

%files
%doc LICENSE README.md examples
%dir %{_sysconfdir}/puppet
%dir %{_sysconfdir}/puppet/modules
%config(noreplace) %{_sysconfdir}/puppet/puppet.conf
%config(noreplace) %{_sysconfdir}/puppet/auth.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/puppet
%{_sysconfdir}/logcheck/ignore.d.workstation/puppet
%{_sysconfdir}/logcheck/ignore.d.server/puppet
%{_tmpfilesdir}/puppet.conf
%{_unitdir}/puppetagent.service
%{_bindir}/puppet
%{_bindir}/extlookup2hiera
%{ruby_vendorlibdir}/hiera
%{ruby_vendorlibdir}/hiera_puppet.rb
%{ruby_vendorlibdir}/puppet
%{ruby_vendorlibdir}/puppet.rb
%{ruby_vendorlibdir}/semver.rb
%{_datadir}/puppet
%attr(-,puppet,puppet) %{_localstatedir}/log/puppet
%attr(-,puppet,puppet) %{_localstatedir}/lib/puppet
%{_mandir}/man5/puppet.conf.5.*
%{_mandir}/man8/puppet.8.*
%{_mandir}/man8/puppet-agent.8.*
%{_mandir}/man8/puppet-apply.8.*
%{_mandir}/man8/puppet-catalog.8.*
%{_mandir}/man8/puppet-describe.8.*
%{_mandir}/man8/puppet-ca.8.*
%{_mandir}/man8/puppet-cert.8.*
%{_mandir}/man8/puppet-certificate.8.*
%{_mandir}/man8/puppet-certificate_request.8.*
%{_mandir}/man8/puppet-certificate_revocation_list.8.*
%{_mandir}/man8/puppet-config.8.*
%{_mandir}/man8/puppet-device.8.*
%{_mandir}/man8/puppet-doc.8.*
%{_mandir}/man8/puppet-facts.8.*
%{_mandir}/man8/puppet-file.8.*
%{_mandir}/man8/puppet-filebucket.8.*
%{_mandir}/man8/puppet-help.8.*
%{_mandir}/man8/puppet-inspect.8.*
%{_mandir}/man8/puppet-instrumentation_data.8.*
%{_mandir}/man8/puppet-instrumentation_listener.8.*
%{_mandir}/man8/puppet-instrumentation_probe.8.*
%{_mandir}/man8/puppet-key.8.*
%{_mandir}/man8/puppet-man.8.*
%{_mandir}/man8/puppet-module.8.*
%{_mandir}/man8/puppet-node.8.*
%{_mandir}/man8/puppet-parser.8.*
%{_mandir}/man8/puppet-plugin.8.*
%{_mandir}/man8/puppet-report.8.*
%{_mandir}/man8/puppet-resource.8.*
%{_mandir}/man8/puppet-resource_type.8.*
%{_mandir}/man8/puppet-secret_agent.8.*
%{_mandir}/man8/puppet-status.8.*
%{_mandir}/man8/extlookup2hiera.8.*

%files server
%{_unitdir}/puppetmaster.service
%config(noreplace) %{_sysconfdir}/puppet/fileserver.conf
%dir %{_sysconfdir}/puppet/manifests
%{_mandir}/man8/puppet-kick.8.*
%{_mandir}/man8/puppet-master.8.*
%{_mandir}/man8/puppet-queue.8.*

%files -n vim-puppet3
%{_datadir}/vim/syntax/puppet.vim
%{_datadir}/vim/ftdetect/puppet.vim

%files -n emacs-puppet3
%{_datadir}/emacs/site-lisp/puppet-mode.el
%{_datadir}/emacs/site-lisp/site-start.d/puppet-mode-init.el


%changelog
* Sun Jan 12 2014 guillomovitch <guillomovitch> 3.2.4-1.2.mga3
+ Revision: 566360
- fix regression introduced by CVE-2013-4969 patch
- add debian patch to fix CVE-2013-4969

  + oden <oden>
    - 3.2.4 (fixes CVE-2013-4761, CVE-2013-4956)

  + boklm <boklm>
    - Remove patch 0001-18781-Be-more-tolerant-of-old-clients-in-WEBrick-ser.patch,
      included in version 3.2.0.
    - Update to version 3.2.2 in order to fix CVE-2013-3567 (Unauthenticated
      Remote Code Execution Vulnerability)

* Sat May 11 2013 guillomovitch <guillomovitch> 3.1.1-4.mga3
+ Revision: 413011
- use systemctl in logrotate, instead of sysinit script

* Fri Apr 05 2013 guillomovitch <guillomovitch> 3.1.1-3.mga3
+ Revision: 408246
- rename puppet syntax files, packages, and make them conflict with those provided by default puppet package

* Sun Mar 24 2013 colin <colin> 3.1.1-2.mga3
+ Revision: 404859
- Add systemd requires and general post/pre fixes (mga#9302)

* Sun Mar 17 2013 guillomovitch <guillomovitch> 3.1.1-1.mga3
+ Revision: 403509
- imported package puppet3

